@@ -33,9 +33,8 @@ ToolTipDialog::ToolTipDialog()
     }
     setFlags(flags);
 
-    m_showTimer = new QTimer(this);
-    m_showTimer->setSingleShot(true);
-    connect(m_showTimer, &QTimer::timeout, this, [this]() {
+    m_hideTimer.setSingleShot(true);
+    connect(&m_hideTimer, &QTimer::timeout, this, [this]() {
         setVisible(false);
     });
 
@@ -46,11 +45,11 @@ ToolTipDialog::ToolTipDialog()
         }
         m_lastMainItem = mainItem();
 
-        if (!mainItem()) {
+        if (!m_lastMainItem) {
             return;
         }
-        connect(mainItem(), &QQuickItem::implicitWidthChanged, this, &ToolTipDialog::updateSize);
-        connect(mainItem(), &QQuickItem::implicitHeightChanged, this, &ToolTipDialog::updateSize);
+        connect(m_lastMainItem, &QQuickItem::implicitWidthChanged, this, &ToolTipDialog::updateSize);
+        connect(m_lastMainItem, &QQuickItem::implicitHeightChanged, this, &ToolTipDialog::updateSize);
         updateSize();
     });
 }
@@ -80,7 +79,7 @@ QQuickItem *ToolTipDialog::loadDefaultItem()
     }
 
     if (!m_qmlObject->rootObject()) {
-        m_qmlObject->setSource(QUrl(QStringLiteral("qrc:/plasma/DefaultToolTip.qml")));
+        m_qmlObject->setSourceFromModule("org.kde.plasma.core", "DefaultToolTip");
     }
 
     return qobject_cast<QQuickItem *>(m_qmlObject->rootObject());
@@ -95,8 +94,7 @@ void ToolTipDialog::showEvent(QShowEvent *event)
 
 void ToolTipDialog::hideEvent(QHideEvent *event)
 {
-    m_showTimer->stop();
-
+    m_hideTimer.stop();
     PlasmaQuick::PopupPlasmaWindow::hideEvent(event);
 }
 
@@ -104,7 +102,7 @@ bool ToolTipDialog::event(QEvent *e)
 {
     if (e->type() == QEvent::Enter) {
         if (m_interactive) {
-            m_showTimer->stop();
+            m_hideTimer.stop();
         }
     } else if (e->type() == QEvent::Leave) {
         dismiss();
@@ -125,15 +123,15 @@ void ToolTipDialog::setOwner(QObject *owner)
 
 void ToolTipDialog::dismiss()
 {
-    m_showTimer->start(200);
+    m_hideTimer.start(200);
 }
 
 void ToolTipDialog::keepalive()
 {
     if (m_hideTimeout > 0) {
-        m_showTimer->start(m_hideTimeout);
+        m_hideTimer.start(m_hideTimeout);
     } else {
-        m_showTimer->stop();
+        m_hideTimer.stop();
     }
 }
 
