@@ -18,7 +18,7 @@
 #include <KConfigGroup>
 #include <plasma/plasma_export.h>
 
-#include <plasma/plasma.h>
+#include <Plasma/Plasma>
 
 namespace KPackage
 {
@@ -717,6 +717,13 @@ Q_SIGNALS:
      */
     void activated();
 
+    /**
+     * Emitted when activation is requested due to, for example, middle
+     * click.
+     * @since 6.3
+     */
+    void secondaryActivated();
+
     // TODO: fix usage in containment, port to QObject::destroyed
     /**
      * Emitted when the applet is deleted
@@ -733,6 +740,9 @@ Q_SIGNALS:
      */
     void locationChanged(Plasma::Types::Location location);
 
+    /**
+     * Emitted when the containment display hints change
+     */
     void containmentDisplayHintsChanged(Plasma::Types::ContainmentDisplayHints hints);
 
     /**
@@ -753,7 +763,7 @@ Q_SIGNALS:
      * Emitted when the constraint hints changed
      * @see setConstraintHints
      */
-    void constraintHintsChanged(ConstraintHints constraintHints);
+    void constraintHintsChanged(Plasma::Applet::ConstraintHints constraintHints);
 
     /**
      * Emitted when the containment changes
