@@ -49,7 +49,7 @@ Containment::Containment(QObject *parentObject, const KPluginMetaData &data, con
     setHasConfigurationInterface(true);
 
     // Try to determine the containment type. It must be done as soon as possible
-    const QString type = pluginMetaData().value(QStringLiteral("X-Plasma-ContainmentType"));
+    const QString type = pluginMetaData().value(u"X-Plasma-ContainmentType");
     QMetaEnum metaEnum = QMetaEnum::fromType<Plasma::Containment::Type>();
     d->type = (Plasma::Containment::Type)metaEnum.keyToValue(type.toLocal8Bit().constData());
     if (d->type == Plasma::Containment::Type::NoContainment) {
@@ -70,12 +70,12 @@ void Containment::init()
     Applet::init();
 
     connect(corona(), &Plasma::Corona::availableScreenRectChanged, this, [this](int screenId) {
-        if (screenId == screen() || screenId == lastScreen()) {
+        if (screenId == screen()) {
             Q_EMIT availableRelativeScreenRectChanged(availableRelativeScreenRect());
         }
     });
     connect(corona(), &Plasma::Corona::availableScreenRegionChanged, this, [this](int screenId) {
-        if (screenId == screen() || screenId == lastScreen()) {
+        if (screenId == screen()) {
             Q_EMIT availableRelativeScreenRegionChanged(availableRelativeScreenRegion());
         }
     });
@@ -417,7 +417,7 @@ void Containment::addApplet(Applet *applet, const QRectF &geometryHint)
     }
 
     // make sure the applets are sorted by id
-    auto position = std::lower_bound(d->applets.begin(), d->applets.end(), applet, [](Plasma::Applet *a1, Plasma::Applet *a2) {
+    const auto position = std::lower_bound(d->applets.begin(), d->applets.end(), applet, [](Plasma::Applet *a1, Plasma::Applet *a2) {
         return a1->id() < a2->id();
     });
     Q_EMIT appletAboutToBeAdded(applet, geometryHint);
@@ -666,14 +666,18 @@ void Containment::reactToScreenChange()
 {
     int newScreen = screen();
 
+    Q_EMIT screenChanged(newScreen);
+
     if (newScreen >= 0) {
         d->lastScreen = newScreen;
         KConfigGroup c = config();
         c.writeEntry("lastScreen", d->lastScreen);
         Q_EMIT configNeedsSaving();
-    }
 
-    Q_EMIT screenChanged(newScreen);
+        Q_EMIT availableRelativeScreenRectChanged(availableRelativeScreenRect());
+        Q_EMIT screenGeometryChanged(screenGeometry());
+        Q_EMIT availableRelativeScreenRegionChanged(availableRelativeScreenRegion());
+    }
 }
 
 } // Plasma namespace
