@@ -63,7 +63,7 @@ Applet *PluginLoader::loadApplet(const QString &name, uint appletId, const QVari
 
     // If the applet is using another applet package, search for the plugin of the other applet
     if (!plugin.isValid()) {
-        const QString parentPlugin = p.metadata().value(QStringLiteral("X-Plasma-RootPath"));
+        const QString parentPlugin = p.metadata().value(u"X-Plasma-RootPath");
         if (!parentPlugin.isEmpty()) {
             plugin = KPluginMetaData(QStringLiteral("plasma/applets/") + parentPlugin, KPluginMetaData::AllowEmptyMetaData);
         }
@@ -94,7 +94,7 @@ Applet *PluginLoader::loadApplet(const QString &name, uint appletId, const QVari
             // without having to construct a fake JSON metadata object.
             // This would help with better error messages which would
             // at least show the missing applet's ID.
-            const auto fakeFileName = name + u'.';
+            const QString fakeFileName = name + u'.';
             metadata = KPluginMetaData(QJsonObject(), fakeFileName);
         }
         applet = new Applet(nullptr, metadata, allArgs);
@@ -109,6 +109,8 @@ Applet *PluginLoader::loadApplet(const QString &name, uint appletId, const QVari
 
 ContainmentActions *PluginLoader::loadContainmentActions(Containment *parent, const QString &name, const QVariantList &args)
 {
+    Q_UNUSED(parent)
+    Q_UNUSED(args)
     if (name.isEmpty()) {
         return nullptr;
     }
@@ -186,7 +188,7 @@ QList<KPluginMetaData> PluginLoader::listAppletMetaData(const QString &category)
 QList<KPluginMetaData> PluginLoader::listAppletMetaDataForMimeType(const QString &mimeType)
 {
     auto filter = [&mimeType](const KPluginMetaData &md) -> bool {
-        return md.value(QStringLiteral("X-Plasma-DropMimeTypes"), QStringList()).contains(mimeType);
+        return md.value(u"X-Plasma-DropMimeTypes", QStringList()).contains(mimeType);
     };
     return KPackage::PackageLoader::self()->findPackages(QStringLiteral("Plasma/Applet"), QString(), filter);
 }
@@ -194,13 +196,13 @@ QList<KPluginMetaData> PluginLoader::listAppletMetaDataForMimeType(const QString
 QList<KPluginMetaData> PluginLoader::listAppletMetaDataForUrl(const QUrl &url)
 {
     auto filter = [](const KPluginMetaData &md) -> bool {
-        return !md.value(QStringLiteral("X-Plasma-DropUrlPatterns"), QStringList()).isEmpty();
+        return !md.value(u"X-Plasma-DropUrlPatterns", QStringList()).isEmpty();
     };
     const QList<KPluginMetaData> allApplets = KPackage::PackageLoader::self()->findPackages(QStringLiteral("Plasma/Applet"), QString(), filter);
 
     QList<KPluginMetaData> filtered;
     for (const KPluginMetaData &md : allApplets) {
-        const QStringList urlPatterns = md.value(QStringLiteral("X-Plasma-DropUrlPatterns"), QStringList());
+        const QStringList urlPatterns = md.value(u"X-Plasma-DropUrlPatterns", QStringList());
         for (const QString &glob : urlPatterns) {
             QRegularExpression rx(QRegularExpression::anchoredPattern(QRegularExpression::wildcardToRegularExpression(glob)));
             if (rx.match(url.toString()).hasMatch()) {
@@ -224,7 +226,7 @@ QList<KPluginMetaData> PluginLoader::listContainmentsMetaData(std::function<bool
 QList<KPluginMetaData> PluginLoader::listContainmentsMetaDataOfType(const QString &type)
 {
     auto filter = [type](const KPluginMetaData &md) -> bool {
-        return md.value(QStringLiteral("X-Plasma-ContainmentType")) == type;
+        return md.value(u"X-Plasma-ContainmentType") == type;
     };
 
     return listContainmentsMetaData(filter);
@@ -233,7 +235,7 @@ QList<KPluginMetaData> PluginLoader::listContainmentsMetaDataOfType(const QStrin
 QList<KPluginMetaData> PluginLoader::listContainmentActionsMetaData(const QString &parentApp)
 {
     auto filter = [&parentApp](const KPluginMetaData &md) -> bool {
-        return md.value(QStringLiteral("X-KDE-ParentApp")) == parentApp;
+        return md.value(u"X-KDE-ParentApp") == parentApp;
     };
 
     QList<KPluginMetaData> plugins;
