@@ -37,9 +37,6 @@ Theme::Theme(QObject *parent)
     if (!ThemePrivate::globalTheme) {
         ThemePrivate::globalTheme = new ThemePrivate;
         ThemePrivate::globalTheme->settingsChanged(false);
-        if (QCoreApplication::instance()) {
-            connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, ThemePrivate::globalTheme, &ThemePrivate::onAppExitCleanup);
-        }
     }
     ThemePrivate::globalTheme->ref.ref();
     d = ThemePrivate::globalTheme;
@@ -55,19 +52,12 @@ Theme::Theme(const QString &themeName, QObject *parent)
     auto &priv = ThemePrivate::themes[themeName];
     if (!priv) {
         priv = new ThemePrivate;
-        if (QCoreApplication::instance()) {
-            connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, priv, &ThemePrivate::onAppExitCleanup);
-        }
     }
 
     priv->ref.ref();
     d = priv;
 
-    // turn off caching so we don't accidentally trigger unnecessary disk activity at this point
-    bool useCache = d->cacheTheme;
-    d->cacheTheme = false;
     d->setThemeName(themeName, false, false);
-    d->cacheTheme = useCache;
     d->fixedName = true;
     connect(d, &ThemePrivate::themeChanged, this, &Theme::themeChanged);
 }
@@ -103,9 +93,6 @@ void Theme::setThemeName(const QString &themeName)
         auto &priv = ThemePrivate::themes[themeName];
         if (!priv) {
             priv = new ThemePrivate;
-            if (QCoreApplication::instance()) {
-                connect(QCoreApplication::instance(), &QCoreApplication::aboutToQuit, priv, &ThemePrivate::onAppExitCleanup);
-            }
         }
         priv->ref.ref();
         d = priv;
@@ -175,6 +162,15 @@ QPalette Theme::globalPalette()
     return ThemePrivate::globalTheme->palette;
 }
 
+KSharedConfigPtr Theme::globalColorScheme()
+{
+    if (!ThemePrivate::globalTheme) {
+        ThemePrivate::globalTheme = new ThemePrivate;
+        ThemePrivate::globalTheme->settingsChanged(false);
+    }
+    return ThemePrivate::globalTheme->colors;
+}
+
 QString Theme::wallpaperPath(const QSize &size) const
 {
     QString fullPath;
