@@ -90,12 +90,10 @@ AppletPopup::AppletPopup()
     });
 
     auto updateWindowResizerEdges = [windowResizer, this]() {
-        Qt::Edges activeEdges = borders();
-        activeEdges.setFlag(PlasmaQuickPrivate::oppositeEdge(effectivePopupDirection()), false);
-        windowResizer->setActiveEdges(activeEdges);
+        windowResizer->setActiveEdges(~nearbyBorders());
     };
     updateWindowResizerEdges();
-    connect(this, &PlasmaWindow::bordersChanged, this, updateWindowResizerEdges);
+    connect(this, &PopupPlasmaWindow::nearbyBordersChanged, this, updateWindowResizerEdges);
     connect(this, &PopupPlasmaWindow::effectivePopupDirectionChanged, this, updateWindowResizerEdges);
 
     connect(this, &PlasmaWindow::mainItemChanged, this, &AppletPopup::onMainItemChanged);
@@ -272,7 +270,10 @@ void AppletPopup::updateSize()
         std::min(std::max(minimumSize().height(), wantedSize.height()), maximumSize().height())
     };
 
-    resize(size);
+    Q_ASSERT(!size.isEmpty());
+    if (!size.isEmpty()) {
+        resize(size);
+    }
 }
 
 LayoutChangedProxy::LayoutChangedProxy(QQuickItem *item)
@@ -346,3 +347,5 @@ QSize LayoutChangedProxy::minimumSize() const
 }
 
 #include "appletpopup.moc"
+
+#include "moc_appletpopup.cpp"
